package coffeeshop;

import static spark.Spark.*;

import java.util.*;

import javax.servlet.http.HttpServletResponse;

import com.google.gson.Gson;

/** Web server handling (parts of) user story 1 and 3 from
 * "How to GET a Cup of Coffee" by Webber, Parastatidis, and
 * Robinson (2008).
 *
 * Created by Henrik Baerbak Christensen, AU.
 */
public class Server {

  private int id = 100;
  private Gson gson = new Gson();
  // Our 'database' of coffee orders...
  private Map<String,Order> db = new HashMap<String,Order>();

  public static void main(String[] args) {
    new Server();
  }
  
  public Server() {
    // === Story 1 ===
    /**
     * POST /order. 
     */
    post("/order", (req, res) -> {
        // Convert from JSON into object format
        Order order = gson.fromJson(req.body(), Order.class);
        // The order is without cost, so we create a proper object
        order = new Order(order.getDrink());
        
        // Create a new resource ID
        String idAsString = "" + id++;
        
        // Store order in the database
        db.put(idAsString, order);
        
        // 201 Created
        res.status(HttpServletResponse.SC_CREATED);
        res.type("application/json");
        
        // Location = URL of created resource
        res.header("Location", req.host() + "/order/" + idAsString);
        
        System.out.println("POST ORDER --> " + order);
        
        // Return the constructed order
        return gson.toJson(order);
      });

    /**
     * GET /order/<id>. Get the order with the given id
     */
    get("/order/:id", (req, res) -> {
        // Extract the order id from the request
        String id = req.params(":id");
        
        // Lookup, and return if found
        Order order = db.get(id);
        System.out.println("GET ORDER --> " + order);
        
        res.type("application/json");
        if (order != null) {
          return gson.toJson(order);
        }
        
        // Otherwise, return error
        res.status(HttpServletResponse.SC_NOT_FOUND);
        
        return gson.toJson(null);
      });
    
    // === Story 2 ===
    /**
     * PUT /order/
     */
    
    // === Story 3 ===
    /**
     * PUT /payment/order or similiar
     */
  }
}
